==> rill-0.0.48.tgz: package/server/hijackBrowser/handlers.js <==
/** Rill v0.0.48 https://www.npmjs.com/package/rill License: MIT*/
var goTo, serlialize, urllite;

serlialize = require("form-serialize");

urllite = require("urllite");

module.exports = {

  /*
  	 * Handle an event that changed the url (popstate or page load)
  	#
  	 * @param {Object} event
   */
  handleChange: function(event) {
    return goTo(window.location.href, {
      method: "GET",
      replaceState: true
    });
  },

  /*
  	 * Handle intercepting form and link clicks to update the url.
  	#
  	 * @param {Object} event
   */
  handleClick: function(event) {
    var el, host, protocol, ref, url;
    if (event.defaultPrevented || event.metaKey || event.ctrlKey || event.shiftKey || event.button !== 0) {
      return;
    }
    el = event.target;
    while ((el != null) && el.nodeName !== 'A' && el.nodeName !== "FORM") {
      el = el.parentNode;
    }
    if (el == null) {
      return;
    }
    if (el.target && el.target !== "_self") {
      return;
    }
    if (Boolean(el.attributes.download)) {
      return;
    }
    url = el.href || el.action;
    ref = urllite(url), protocol = ref.protocol, host = ref.host;
    if (protocol !== window.location.protocol || host !== window.location.host) {
      return;
    }
    if (el.rel && /(?:^|\s+)external(?:\s+|$)/.test(el.rel)) {
      return;
    }
    goTo(url, {
      method: el.method,
      body: el.nodeName === "FORM" ? serlialize(el) : void 0
    });
    return event.preventDefault();
  }
};

goTo = require("./index").goTo;

==> rill-0.0.49.tgz: package/server/hijackBrowser/handlers.js <==
/** Rill v0.0.49 https://www.npmjs.com/package/rill License: MIT*/
var goTo, parseURL, serlialize;

serlialize = require("form-serialize");

parseURL = require("parse-url");

module.exports = {

  /*
  	 * Handle an event that changed the url (popstate or page load)
  	#
  	 * @param {Object} event
   */
  handleChange: function(event) {
    return goTo(window.location.href, {
      method: "GET",
      replaceState: true
    });
  },

  /*
  	 * Handle intercepting form and link clicks to update the url.
  	#
  	 * @param {Object} event
   */
  handleClick: function(event) {
    var el, host, protocol, ref, url;
    if (event.defaultPrevented || event.metaKey || event.ctrlKey || event.shiftKey || event.button !== 0) {
      return;
    }
    el = event.target;
    while ((el != null) && el.nodeName !== 'A' && el.nodeName !== "FORM") {
      el = el.parentNode;
    }
    if (el == null) {
      return;
    }
    if (el.target && el.target !== "_self") {
      return;
    }
    if (Boolean(el.attributes.download)) {
      return;
    }
    url = el.href || el.action;
    ref = parseURL(url, {
      defaults: window.location
    }), protocol = ref.protocol, host = ref.host;
    if (!(window.location.protocol.indexOf(protocol) !== -1 && window.location.host === host)) {
      return;
    }
    if (el.rel && /(?:^|\s+)external(?:\s+|$)/.test(el.rel)) {
      return;
    }
    goTo(url, {
      method: el.method,
      body: el.nodeName === "FORM" ? serlialize(el) : void 0
    });
    return event.preventDefault();
  }
};

goTo = require("./index").goTo;
